==> haskell-gi-cairo-connector-0.1.1-267-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-2imJo5S0imTD0rN7ArTZSs
key:                  gi-cairo-connector-0.1.1-2imJo5S0imTD0rN7ArTZSs
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  b53b163a33eb2d4320d3065d623edee1
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-2imJo5S0imTD0rN7ArTZSs
depends:
    base-4.17.2.1 gi-cairo-1.0.29-LIB7fYVWqLpKdhr7eB8lrL
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-cairo-connector-0.1.1-268-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-cairo-connector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-cairo-connector
version:              0.1.1
visibility:           public
id:                   gi-cairo-connector-0.1.1-BmGZfhe4vtwdsaufV68HT
key:                  gi-cairo-connector-0.1.1-BmGZfhe4vtwdsaufV68HT
license:              LGPL-2.1-only
copyright:            (c) 2018 Kilian Kilger, Iñaki García Etxebarria
maintainer:           Kilian Kilger (kkilger@gmail.com)
author:
    Iñaki García Etxebarria,
    Kilian Kilger

stability:            experimental
homepage:             https://github.com/cohomology/gi-cairo-render
synopsis:             GI friendly Binding to the Cairo library.
description:
    This library contains glue code used to interconnect Haskell GI and Cairo

category:             Graphics
abi:                  f6375f87623632bf1975a59b05d55f63
exposed:              True
exposed-modules:      GI.Cairo.Render.Connector
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-cairo-connector-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-cairo-connector
hs-libraries:         HSgi-cairo-connector-0.1.1-BmGZfhe4vtwdsaufV68HT
depends:
    base-4.17.2.1 gi-cairo-1.0.29-9cPYMOdSRilFBgLUBoIly
    gi-cairo-render-0.1.2-D8cwROZxHFODvu2ELuFuxo
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT mtl-2.2.2

haddock-interfaces:
    /usr/share/doc/haskell-gi-cairo-connector/html/gi-cairo-connector.haddock

haddock-html:         /usr/share/doc/haskell-gi-cairo-connector/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
